@@ -1,11 +1,11 @@
-qi.polr <- function(object, par, x = x, x1 = NULL) {
+qi.polr <- function(object, simpar, x = x, x1 = NULL) {
   m <- ncol(x)
   lev <- object$lev
   k <- length(lev)
-  ev.multinom<-function(num, simpar, x, lev, k, m){
+  ev.multinom<-function(num, sims, x, lev, k, m){
     eta <- NULL
     for (i in 1:(k-1))
-      eta <- cbind(eta, simpar[,(m*(i-1)+1):(m*i)]%*%t(x))
+      eta <- cbind(eta, sims[,(m*(i-1)+1):(m*i)]%*%t(x))
     eta <- exp(cbind(rep(0, num), eta))
     ev <- eta/apply(eta, 1, sum)
     colnames(ev) <- lev
