@@ -8,7 +8,7 @@ user.prompt()
 z.out1 <- zelig(as.factor(cost) ~ mil + coop, model = "oprobit", 
                     data = sanction)
 user.prompt()
-print(summary(z.out1))
+summary(z.out1)
 
 # Set the explanatory variables to their means, with 'mil' set
 # to 0 (no military action in addition to sanctions) in the baseline
@@ -23,8 +23,7 @@ x.high <- setx(z.out1, mil = 1)
 user.prompt()
 s.out1 <- sim(z.out1, x = x.low, x1 = x.high)
 user.prompt()
-print(summary(s.out1))
-
+summary(s.out1)
 
 ##### Example 2: Creating An Ordered Dependent Variable #####
 
@@ -38,7 +37,7 @@ sanction$ncost <- factor(sanction$ncost, ordered = TRUE,
 user.prompt()
 z.out2 <- zelig(ncost ~ mil + coop, model = "oprobit", data = sanction)
 user.prompt()
-print(summary(z.out2))
+summary(z.out2)
 
 # Set the explanatory variables to their observed values:  
 user.prompt()
@@ -48,7 +47,7 @@ x.out2 <- setx(z.out2, fn = NULL)
 user.prompt()
 s.out2 <- sim(z.out2, x = x.out2)
 user.prompt()
-print(summary(s.out2))
+summary(s.out2)
 
 
 
