@@ -8,8 +8,8 @@ data(coalition)
 ##  object using the selected explanatory variables:  
 user.prompt()
 z.out <- zelig(Surv(duration, ciep12) ~ invest + polar + numst2 + crisis,
-               model = "weibull", data = coalition)
-
+               model = "weibull", data = coalition, robust = TRUE)
+user.prompt()
 ##  Viewing the regression output.  Note that the Weibull model
 ##  differs from the exponential model in that the Weibull has an
 ##  optional scale parameter.  (The exponential is a special case of
@@ -24,7 +24,7 @@ x.out <- setx(z.out)
 ##  Simulating draws from the posterior distribution.
 user.prompt()
 s.out <- sim(z.out, x = x.out)
-
+user.prompt()
 ##  Viewing the simulated quantities of interest (in this case, the
 ##  expected value is the ceteris paribus predicted duration): 
 summary(s.out)
